@@ -1,13 +1,14 @@
 ;;; winring.el --- Window configuration rings
 
-;; Copyright (C) 1998 Free Software Foundation, Inc.
+;; Copyright (C) 1998, 1999 Free Software Foundation, Inc.
 
-;; Author:	1997-1998 Barry A. Warsaw
-;; Maintainer:	bwarsaw@python.org
-;; Created:	March 1997
-;; Keywords:	frames tools
+;; Author:   1997-2004 Barry A. Warsaw
+;; Contact:  gnu@wooz.org (Barry A. Warsaw)
+;; Homepage: http://barry.warsaw.us/elisp
+;; Created:  March 1997
+;; Keywords: frames tools
 
-(defconst winring-version "3.5"
+(defconst winring-version "$Revision: 1.2 $"
   "winring version number.")
 
 ;; This file is part of GNU Emacs.
@@ -117,13 +118,6 @@
 ;; names are shown, you can change this by passing in your own
 ;; modeline hacker function to `winring-initialize'.
 
-;;; Winring on the Web:
-;;
-;; The winring Web page (including the aforementioned XEmacs 20.4
-;; patch) is
-;;
-;;    http://www.python.org/emacs/winring/
-
 ;;; History:
 ;;
 ;; A long long time ago there was a package called `wicos' written by
@@ -147,7 +141,7 @@
 ;;
 ;; I know of a few other related packages:
 ;;
-;;     - `escreen' by Noah Friedman.  A much more ambitious package
+;;    - `escreen' by Noah Friedman.  A much more ambitious package
 ;;       that does Emacs window session management.  Very cool, but I
 ;;       wanted something more lightweight.
 ;;
@@ -161,10 +155,14 @@
 ;;      semantics to window configuration changes.  winner is a minor
 ;;      mode and does seem to support frame-specific window rings.
 ;;
-;;    - `window-xemacs' by the XEmacs Development Team.  It appears
-;;      that this package, which is specific to XEmacs (and perhaps
-;;      just XEmacs 20) implements stacks of window configurations
-;;      which are frame independent.
+;;    - `tapestry' by Kyle Jones and distributed with the VM package.
+;;      A much more featured package, but there is a lot of overlap
+;;      and it seems more designed for programmatic rather than
+;;      interactive use.
+
+;;    - XEmacs has some built-in support for window configuration
+;;      stacks, but I wanted to use a ring structure for managing
+;;      configurations.
 
 ;; Please feel free to email me if my rendition of history, or my
 ;; explanation of the related packages, is inaccurate.
@@ -305,7 +303,6 @@ not given then the currently selected frame is used."
 	;; The XEmacs way.  Only supported in hacked 20.4 or 21.0
 	(add-spec-to-specifier winring-name name frame)
       ;; the Emacs way.  Only supported in Emacs 20.3
-      (setq winring-name name)
       (modify-frame-parameters frame (list (cons 'winring-name name)))
       ))
   (if (not winring-show-names)
@@ -476,10 +473,10 @@ With \\[universal-argument] prompt for named configuration to delete."
       )))
 
 ;;;###autoload
-(defun winring-rename-configuration (name)
+(defun winring-rename-configuration ()
   "Rename the current configuration to NAME."
-  (interactive "sNew window configuration name? ")
-  (winring-set-name name))
+  (interactive)
+  (winring-set-name (winring-read-name "New window configuration name? ")))
 
 
 
